@@ -3,8 +3,11 @@
  *  @file autogen.c
  *
  *  This is the main routine for autogen.
- *
- *  This file is part of AutoGen.
+ *  @addtogroup autogen
+ *  @{
+ */
+
+/*  This file is part of AutoGen.
  *  Copyright (C) 1992-2013 Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
@@ -203,6 +206,12 @@ exit_cleanup(wait_for_pclose_enum_t cl_wait)
 static void
 cleanup_and_abort(int sig)
 {
+    int sig_exit_code = AUTOGEN_EXIT_SIGNAL + sig;
+    if (processing_state == PROC_STATE_INIT) {
+        fprintf(stderr, AG_NEVER_STARTED, sig, strsignal(sig));
+        exit(sig_exit_code);
+    }
+
     if (*oops_pfx != NUL) {
         fputs(oops_pfx, stderr);
         oops_pfx = zNil;
@@ -214,7 +223,7 @@ cleanup_and_abort(int sig)
 
     if (processing_state == PROC_STATE_ABORTING) {
         exit_cleanup(EXIT_PCLOSE_NOWAIT);
-        _exit(sig + 128);
+        exit(sig_exit_code);
     }
 
     processing_state = PROC_STATE_ABORTING;
@@ -279,14 +288,14 @@ catch_sig_and_bail(int sig)
 {
     switch (processing_state) {
     case PROC_STATE_ABORTING:
-        exit_code = AUTOGEN_EXIT_SIGNAL;
+        exit_code = AUTOGEN_EXIT_SIGNAL + sig;
 
     case PROC_STATE_DONE:
         break;
 
     default:
         abend_sig = sig;
-        exit_code = AUTOGEN_EXIT_SIGNAL;
+        exit_code = AUTOGEN_EXIT_SIGNAL + sig;
         siglongjmp(abend_env, sig);
     }
 }
@@ -426,7 +435,7 @@ done_check(void)
         cgi_stderr = NULL;
     }
 
-    ag_scribble_deinit();
+    scribble_deinit();
 
     if (OPT_VALUE_TRACE > TRACE_NOTHING)
         fprintf(trace_fp, DONE_CHECK_DONE);
@@ -440,7 +449,7 @@ done_check(void)
      *  of inner_main().)
      */
     if (processing_state != PROC_STATE_OPTIONS)
-        _exit(exit_code);
+        exit(exit_code);
 }
 
 
@@ -536,6 +545,9 @@ setup_signals(sighandler_proc_t * chldHandler,
              */
 #ifdef SIGTSTP
         case SIGTSTP:
+#endif
+#ifdef SIGPROF
+        case SIGPROF:
 #endif
             continue;
 
@@ -632,7 +644,9 @@ ao_strdup (char const * str)
         (void)option_load_mode, (void)program_pkgdatadir;
     }
 #endif
-/*
+/**
+ * @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
