@@ -1,11 +1,17 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for autoopts
- * Generated Fri Jan  4 21:29:33 PST 2013
+ * Generated Sat May 18 08:03:20 PDT 2013
  */
 #ifndef AUTOOPTS_PROTO_H_GUARD
 #define AUTOOPTS_PROTO_H_GUARD 1
 
+/*
+ *  Extracted from alias.c
+ */
+static tSuccess
+too_many_occurrences(tOptions * opts, tOptDesc * od);
+
 /*
  *  Extracted from autoopts.c
  */
@@ -19,7 +25,7 @@ static char *
 ao_strdup(char const *str);
 
 static tSuccess
-handle_opt(tOptions * pOpts, tOptState * o_st);
+handle_opt(tOptions * opts, tOptState * o_st);
 
 static tSuccess
 next_opt(tOptions * opts, tOptState * o_st);
@@ -39,8 +45,8 @@ is_consistent(tOptions * pOpts);
 static void
 intern_file_load(tOptions * opts);
 
-static char*
-parse_attrs(tOptions * opts, char * txt, tOptionLoadMode * pMode,
+static char const *
+parse_attrs(tOptions * opts, char const * txt, tOptionLoadMode * pMode,
             tOptionValue * pType);
 
 /*
@@ -86,12 +92,17 @@ static void
 munge_str(char * txt, tOptionLoadMode mode);
 
 static void
-loadOptionLine(
-    tOptions *  opts,
-    tOptState * opt_state,
-    char *      line,
-    tDirection  direction,
-    tOptionLoadMode   load_mode );
+loadOptionLine(tOptions * opts, tOptState * opt_state, char * line,
+               tDirection direction, tOptionLoadMode load_mode );
+
+/*
+ *  Extracted from makeshell.c
+ */
+static void
+fserr_warn(char const * prog, char const * op, char const * fname);
+
+static void
+fserr_exit(char const * prog, char const * op, char const * fname);
 
 /*
  *  Extracted from nested.c
@@ -126,4 +137,7 @@ addArgListEntry(void** ppAL, void* entry);
 static void
 set_usage_flags(tOptions * opts, char const * flg_txt);
 
+static void
+ao_bug(char const * msg);
+
 #endif /* AUTOOPTS_PROTO_H_GUARD */
